@@ -11,7 +11,7 @@
  * Author: Damian Waradzyn
  */
 
-#define DOWNLOADING_THREADS 4
+#define DOWNLOADING_THREADS 2
 
 SDL_Thread* downloadThreads[DOWNLOADING_THREADS];
 
@@ -111,9 +111,11 @@ void tileEngine_handleZoomHelperTiles() {
                         && currentPositionZoomHelperTiles[i] -> textureUsedTime > 0 && nowMillis
                         - currentPositionZoomHelperTiles[i] -> textureUsedTime > 3000) {
                     //                    fprintf(stderr, "del tex %d\n", currentPositionZoomHelperTiles[i] -> texture);
-                    glDeleteTextures(1, &currentPositionZoomHelperTiles[i] -> texture);
+
+                    GLuint texture = currentPositionZoomHelperTiles[i] -> texture;
                     currentPositionZoomHelperTiles[i] -> texture = 0;
                     currentPositionZoomHelperTiles[i] -> state = STATE_GL_TEXTURE_NOT_CREATED;
+                    glDeleteTextures(1, &texture);
                     currentPositionZoomHelperTiles[i] -> textureUsedTime = 0;
                 }
             }
@@ -125,7 +127,7 @@ void tileEngine_handleZoomHelperTiles() {
         }
 
         // Limit amount of helper tiles added to queue per second.
-        if (nowMillis - lastZoomHelperTileCreatedMilis < 200) {
+        if (nowMillis - lastZoomHelperTileCreatedMilis < 100) {
             newTile = FALSE;
         }
 
@@ -715,7 +717,7 @@ void activateZoomBar() {
     if (canvas.orientationTransitionLinear < 80) {
         canvas.zoomKnotPosition = knotZoomLevel * (SCREEN_WIDTH - 228) / zoomLevelCount + 114;
     } else {
-        canvas.zoomKnotPosition = -(knotZoomLevel * (SCREEN_HEIGHT - 232) / zoomLevelCount) + SCREEN_HEIGHT - 114-32-14;
+        canvas.zoomKnotPosition = -(knotZoomLevel * (SCREEN_HEIGHT - 232) / zoomLevelCount) + SCREEN_HEIGHT - 114 - 32 - 14;
     }
 }
 
@@ -991,10 +993,11 @@ void tileEngine_computeTilesVisibility() {
                 }
             } else {
                 tiles[i][j][currentTilesIdx] -> visible = FALSE;
-                if (tiles[i][j][currentTilesIdx] -> state == STATE_LOADED || tiles[i][j][currentTilesIdx] -> state == STATE_LOADED_SYNC_WAIT) {
-                    glDeleteTextures(1, &tiles[i][j][currentTilesIdx] -> texture);
+                if ((tiles[i][j][currentTilesIdx] -> state == STATE_LOADED || tiles[i][j][currentTilesIdx] -> state == STATE_LOADED_SYNC_WAIT) && (tiles[i][j][currentTilesIdx] -> texture != 0)) {
+                    GLuint texture = tiles[i][j][currentTilesIdx] -> texture;
                     tiles[i][j][currentTilesIdx] -> texture = 0;
                     tiles[i][j][currentTilesIdx] -> state = STATE_GL_TEXTURE_NOT_CREATED;
+                    glDeleteTextures(1, &texture);
                 }
             }
         }
