@@ -21,8 +21,9 @@ void loadTexture(Texture* texture, char* filename) {
     //    fprintf(stderr, "loadTextureFromFile returned: %p\n", textureRGB);
     if (textureRGB != NULL) {
         texture -> size = textureRGB -> w;
-        texture -> name = createTexture(convert8888to4444(textureRGB, FALSE), texture->size, texture-> size, FALSE);
-        SDL_FreeSurface(textureRGB);
+        //        texture -> name = createTexture(convert8888to4444(textureRGB, FALSE), texture->size, texture-> size, FALSE);
+        //SDL_FreeSurface(textureRGB);
+        texture -> name = createTexture(textureRGB -> pixels, texture->size, texture-> size, FALSE);
     } else {
         fprintf(stderr, "loadTexture %s failed\n", filename);
     }
@@ -773,15 +774,15 @@ void updateUi() {
     zoomKnot -> color.g = canvas.zoomBarAlpha;
     zoomKnot -> color.b = canvas.zoomBarAlpha;
     zoomKnot -> color.a = 1.0;
-//    zoomKnot -> status = UI_HIDDEN;
+    //    zoomKnot -> status = UI_HIDDEN;
     if (canvas.orientationTransitionLinear < 80) {
         zoomKnot -> x += (canvas.zoomKnotPosition - zoomKnot -> x) / 4.0;
         zoomKnot -> y = SCREEN_HEIGHT - 185 - canvas.searchBarY;
-        zoomKnot -> texCoords =  texCoordsLandscape[0];
+        zoomKnot -> texCoords = texCoordsLandscape[0];
     } else {
         zoomKnot -> x = SCREEN_WIDTH - 185 - canvas.searchBarY;
         zoomKnot -> y += (canvas.zoomKnotPosition - zoomKnot -> y) / 4.0;
-        zoomKnot -> texCoords =  texCoordsPortrait[0];
+        zoomKnot -> texCoords = texCoordsPortrait[0];
     }
 }
 
